#!/bin/bash

set -euax

#Get ob number
ob_number=`hostname | cut -c 10- -`

router_ip=172.27.${ob_number}.1
#set apikey variable
apikey=`sudo maas-region-admin apikey --username admin | tail -n1`

setup_juju() {
        mkdir -p /home/ubuntu/.juju
        cat >/home/ubuntu/.juju/environments.yaml <<EOF
default: maas
environments:
    maas:
        type: maas
        maas-server: 'http://${router_ip}/MAAS/'
        maas-oauth: '$apikey'
        default-series: trusty
        #enable-os-upgrade: false
        authorized-keys-path: /home/ubuntu/.ssh/id_rsa.pub
        admin-secret: 'admin'
        logging-config: '<root>=DEBUG'
        lxc-clone: true
EOF
        rm -rf /home/ubuntu/.juju-plugins
        git clone https://github.com/juju/plugins /home/ubuntu/.juju-plugins

        # Change ownership recusrively of specified directory
        sudo chown -R ubuntu:ubuntu /home/ubuntu/

        echo "PATH=\$PATH:/home/ubuntu/.juju-plugins:/home/ubuntu/Examples/bin" >> /home/ubuntu/.bashrc
}

setup_landscape() {
        # The master node will be managed by Landscape
        # TODO: this is currently hardcoded to our own landscape account
        if which landscape-config; then
                case "$(hostname)" in
                        OrangeBox*|orangebox*)
                                landscape-config -a canonical-orange -t "$(hostname)__$(dmidecode -s baseboard-serial-number)" -p ubuntu-aubergine --script-users=ALL --silent --include-manager-plugins=ScriptExecution || true
                        ;;
                esac
        fi
}

setup_desktop() {
        # Sets background image
        gsettings set org.gnome.desktop.background picture-uri file:///home/ubuntu/obpic.png
        # Set bakcground color and gradient
	# Set background primary color to Ubuntu Orange
        gsettings set org.gnome.desktop.background primary-color '#DD4814'
        # Set background secondary color to Dark Aubergine
	gsettings set org.gnome.desktop.background secondary-color '#2C001E'
        # Set background gradient
	gsettings set org.gnome.desktop.background color-shading-type 'vertical'
        # Creates Launchers
        gsettings set com.canonical.Unity.Launcher favorites "['gnome-terminal.desktop','chromium-browser.desktop','firefox.desktop','byobu.desktop','remmina.desktop','virt-manager.desktop']"
        # Disable turning off display
        gsettings set org.gnome.desktop.session idle-delay 0
        # Disable screen saver
        gsettings set org.gnome.desktop.screensaver idle-activation-enabled false
        # Disable screen lock
        gsettings set org.gnome.desktop.screensaver lock-enabled false
        if [ -e /etc/lightdm/lightdm.conf ]; then
                sudo sed -i -e "/autologin-user=/d" /etc/lightdm/users.conf
                sudo echo "autologin-user=ubuntu" >> /etc/lightdm/users.conf
        fi

        # Disable Ubuntu crash reporter
        echo "enabled=0" |sudo tee /etc/default/apport

        # Stop Ubuntu crash reporter
        sudo invoke-rc.d apport stop || true
}

setup_remmina() {
        mkdir /home/ubuntu/.remmina
        for nodenum in {11..20}
        do
             cat >/home/ubuntu/.remmina/node${nodenum}.remmina <<EOF
[remmina]
keymap=
ssh_auth=0
quality=0
disableencryption=0
ssh_charset=
ssh_privatekey=
server=172.27.60.${nodenum}
hscale=0
group=
password=ZAeBA6bAHnfWpo53cMfrmQ==
name=node10
ssh_loopback=0
viewonly=0
ssh_username=
ssh_server=
window_maximize=0
aspectscale=0
protocol=VNC
window_height=825
window_width=963
vscale=0
ssh_enabled=0
username=admin
showcursor=0
disableserverinput=0
colordepth=8
disableclipboard=0
viewmode=1             
EOF
        done
        chown -R ubuntu:ubuntu /home/ubuntu/.remmina
}


setup_juju
setup_landscape
setup_desktop
setup_remmina
/srv/obsetup/import_SA_keys.sh
ln -s /srv/obsetup/demos /home/ubuntu/demos
